@@ -1,13 +1,13 @@
 import argparse
-import logging.config
 import logging
+import logging.config
 import sys
 import textwrap
 import traceback
-
 from logging import debug
-from cli_ui import warning, fatal
+
 import cli_ui
+from cli_ui import warning, error, fatal
 
 from gitlabform import EXIT_INVALID_INPUT, EXIT_PROCESSING_ERROR
 from gitlabform.configuration.core import (
@@ -118,11 +118,13 @@ class GitLabForm(object):
         parser = argparse.ArgumentParser(
             description=textwrap.dedent(
                 f"""
-            Specialized "configuration as a code" tool for GitLab projects, groups and more
+            🏗 Specialized "configuration as a code" tool for GitLab projects, groups and more
             using hierarchical configuration written in YAML.
 
-            Exits with code {EXIT_INVALID_INPUT} on invalid input errors (f.e. config file not found),
-            and with code {EXIT_PROCESSING_ERROR} if the are processing errors (f.e. if GitLab returns 400).
+            Exits with code:
+              * 0 - on success,
+              * {EXIT_INVALID_INPUT} - on invalid input errors (f.e. bad syntax in the config file) ~ "it's your fault". 😅
+              * {EXIT_PROCESSING_ERROR} - if there were backend processing errors (f.e. when requests to GitLab fail) ~ "it's not your fault". 😎
             """
             ),
             formatter_class=Formatter,
@@ -377,16 +379,18 @@ class GitLabForm(object):
                 failed_groups[group_number] = group
 
                 trace = traceback.format_exc()
-                message = f"Error occurred while processing group {group}, exception:\n\n{e}\n\n{trace}"
+                message = (
+                    f"Error occurred while processing group {group}, exception:\n\n{e}"
+                )
 
                 if self.terminate_after_error:
                     effective_configuration.write_to_file()
-                    fatal(
-                        message,
-                        exit_code=EXIT_PROCESSING_ERROR,
-                    )
+                    error(message)
+                    debug(trace)
+                    sys.exit(EXIT_PROCESSING_ERROR)
                 else:
                     warning(message)
+                    debug(trace)
             finally:
                 debug(
                     f"@ ({group_number}/{len(groups)}) FINISHED Processing group: {group}"
@@ -440,17 +444,16 @@ class GitLabForm(object):
                 failed_projects[project_number] = project_and_group
 
                 trace = traceback.format_exc()
-                message = f"Error occurred while processing project {project_and_group}, exception:\n\n{e}\n\n{trace}"
+                message = f"Error occurred while processing project {project_and_group}, exception:\n\n{e}"
 
                 if self.terminate_after_error:
                     effective_configuration.write_to_file()
-                    fatal(
-                        message,
-                        exit_code=EXIT_PROCESSING_ERROR,
-                    )
+                    error(message)
+                    debug(trace)
+                    sys.exit(EXIT_PROCESSING_ERROR)
                 else:
                     warning(message)
-
+                    debug(trace)
             finally:
 
                 debug(
