@@ -8,7 +8,7 @@ from gitlabform.gitlab import GitLab, AccessLevel
 from gitlabform.gitlab.core import NotFoundException, UnexpectedResponseException
 
 CONFIG = """
-config_version: 2
+config_version: 3
 """
 
 DEFAULT_README = "Default README content."
@@ -16,20 +16,23 @@ DEFAULT_README = "Default README content."
 # automate reading files created by run_gitlab_in_docker.sh to run tests in PyCharm / IntelliJ
 # (workaround for lack of this feature: https://youtrack.jetbrains.com/issue/PY-5543 )
 
-env_vars_and_file_paths = {
-    "GITLAB_URL": ["gitlab_url.txt", "../../gitlab_url.txt"],
-    "GITLAB_TOKEN": ["gitlab_token.txt", "../../gitlab_token.txt"],
+env_vars_to_files = {
+    "GITLAB_URL": "gitlab_url.txt",
+    "GITLAB_TOKEN": "gitlab_token.txt",
 }
 
-for env_var, file_paths in env_vars_and_file_paths.items():
+for env_var in env_vars_to_files.keys():
     if env_var not in os.environ:
-        print(f"{env_var} not set - trying to read it from {file_paths} ...")
-        for file_path in file_paths:
+        print(f"{env_var} not set - trying to read it from a file...")
+        for up_dir_level in range(0, 4):
+            file_path = (up_dir_level * "../") + env_vars_to_files[env_var]
+            print(f"Trying to read {file_path} ...")
             if os.path.isfile(file_path):
                 try:
                     with open(file_path, "r") as file:
-                        os.environ[env_var] = file.read().replace("\n", "")
+                        os.environ[env_var] = file.read().strip()
                         print(f"{env_var} set!")
+                        break
                 except Exception as e:
                     print(f"Failed to read {file_path}: {e}")
             else:
@@ -143,7 +146,7 @@ def remove_users_from_group(group_name, usernames):
 def delete_variables_from_group(group_name, variables):
     for variable in variables:
         try:
-            gl.delete_group_secret_variable(group_name, variable)
+            gl.delete_group_variable(group_name, variable)
         except NotFoundException:
             # this is fine - variable is removed from group
             pass
